@@ -11,7 +11,6 @@ from python_common_tools.cache import cache_function, cache_daily_function
 from python_common_tools.linux import get_bash_output, get_latest_commit_id
 from python_common_tools.log import setup_logger
 from python_common_tools.network import secure_requests, secure_requests_json
-from python_common_tools.parallel import run_func_parallel
 import logging
 
 
@@ -148,28 +147,7 @@ def test_func2(i, j):
 
 def test_callback_func(i, r, callback_func_extra_kwargs):
     logger = callback_func_extra_kwargs["logger"]
-    logger.info("i={i},r={r}".format(i=i,r=r))
-
-
-class TestRunFuncParallel(unittest.TestCase):
-    def setUp(self) -> None:
-        self.logger = logging.getLogger("python_common_tools.test")
-
-    def test_run_func_parallel(self):
-        func_args_list1 = list(range(10))
-        callback_func_extra_kwargs = {"logger": self.logger}
-        self.logger.info("test func with one single param in thread style")
-        run_func_parallel(test_func1, func_args_list1, test_callback_func, callback_func_extra_kwargs)
-
-        self.logger.info("test func with one single param in process style")
-        run_func_parallel(test_func1, func_args_list1, test_callback_func, callback_func_extra_kwargs, style="process")
-
-        func_args_list2 = [(i, i) for i in range(10)]
-        self.logger.info("test func with one more param in thread style")
-        run_func_parallel(test_func2, func_args_list2, test_callback_func, callback_func_extra_kwargs)
-
-        self.logger.info("test func with one more param in process style")
-        run_func_parallel(test_func2, func_args_list2, test_callback_func, callback_func_extra_kwargs, style="process")
+    logger.info("i={i},r={r}".format(i=i, r=r))
 
 
 def main():
